@@ -23,7 +23,7 @@ static ext_table_entry ext_mime_table[] =
     {"f90", "text/plain", "7bit", "text"},
     {"gif", "image/gif", "binary", "image"},
     {"gtar", "application/x-gtar", "binary", "binary"},
-    {"gz", "application/x-gzip", "x-gzip", "binary"},
+    {"gz", "text/plain", "x-gzip", "binary"},
     {"h", "text/plain", "7bit", "text"},
     {"hdf", "application/x-hdf", "binary", "binary"},
     {"hh", "text/plain", "7bit", "text"},
@@ -77,7 +77,7 @@ static ext_table_entry ext_mime_table[] =
     {"tex", "application/x-tex", "8bit", "text"},
     {"texi", "application/x-texinfo", "7bit", "text"},
     {"texinfo", "application/x-texinfo", "7bit", "text"},
-    {"tgz", "application/x-gzip", "x-gzip", "binary"},
+    {"tgz", "application/x-tar", "x-gzip", "binary"},
     {"tif", "image/tiff", "binary", "image"},
     {"tiff", "image/tiff", "binary", "image"},
     {"tr", "application/x-troff", "7bit", "text"},
