@@ -1,6 +1,6 @@
 
 /*
- * $Id: ssl.c,v 1.1.2.20 1996/07/08 18:31:06 wessels Exp $
+ * $Id: ssl.c,v 1.1.2.22 1996/07/15 16:15:03 wessels Exp $
  *
  * DEBUG: section 26    Secure Sockets Layer Proxy
  * AUTHOR: Duane Wessels
@@ -157,15 +157,6 @@ static void sslReadServer(fd, sslState)
 	    COMM_SELECT_WRITE,
 	    (PF) sslWriteClient,
 	    (void *) sslState);
-	comm_set_select_handler_plus_timeout(sslState->server.fd,
-	    COMM_SELECT_TIMEOUT,
-	    (PF) sslReadTimeout,
-	    (void *) sslState,
-	    sslState->timeout);
-	comm_set_select_handler(sslState->server.fd,
-	    COMM_SELECT_READ,
-	    (PF) sslReadServer,
-	    (void *) sslState);
     }
 }
 
@@ -186,13 +177,8 @@ static void sslReadClient(fd, sslState)
 	    /* XXX This may loop forever */
 	    comm_set_select_handler(sslState->client.fd,
 		COMM_SELECT_READ,
-		(PF) sslReadServer,
+		(PF) sslReadClient,
 		(void *) sslState);
-	    comm_set_select_handler_plus_timeout(sslState->client.fd,
-		COMM_SELECT_TIMEOUT,
-		(PF) sslReadTimeout,
-		(void *) sslState,
-		sslState->timeout);
 	} else {
 	    sslClose(sslState);
 	}
@@ -206,14 +192,6 @@ static void sslReadClient(fd, sslState)
 	    COMM_SELECT_WRITE,
 	    (PF) sslWriteServer,
 	    (void *) sslState);
-	comm_set_select_handler_plus_timeout(sslState->client.fd, COMM_SELECT_TIMEOUT,
-	    (PF) sslReadTimeout,
-	    (void *) sslState,
-	    sslState->timeout);
-	comm_set_select_handler(sslState->client.fd,
-	    COMM_SELECT_READ,
-	    (PF) sslReadServer,
-	    (void *) sslState);
     }
 }
 
@@ -239,6 +217,11 @@ static void sslWriteServer(fd, sslState)
 	    COMM_SELECT_READ,
 	    (PF) sslReadClient,
 	    (void *) sslState);
+	comm_set_select_handler_plus_timeout(sslState->server.fd,
+	    COMM_SELECT_TIMEOUT,
+	    (PF) sslReadTimeout,
+	    (void *) sslState,
+	    sslState->timeout);
     } else {
 	/* still have more to write */
 	comm_set_select_handler(sslState->server.fd,
@@ -306,15 +289,6 @@ static void sslConnected(fd, sslState)
 	(PF) sslWriteClient,
 	(void *) sslState);
     comm_set_fd_lifetime(fd, 86400);	/* extend lifetime */
-    comm_set_select_handler_plus_timeout(sslState->server.fd,
-	COMM_SELECT_TIMEOUT,
-	(PF) sslReadTimeout,
-	(void *) sslState,
-	sslState->timeout);
-    comm_set_select_handler(sslState->server.fd,
-	COMM_SELECT_READ,
-	(PF) sslReadServer,
-	(void *) sslState);
     comm_set_select_handler(sslState->client.fd,
 	COMM_SELECT_READ,
 	(PF) sslReadClient,
