@@ -1,18 +1,31 @@
-
 /*
- * $Id: url.c,v 1.19.2.16 1996/07/01 22:00:51 wessels Exp $
+ * $Id: url.c,v 1.19.2.18 1996/07/08 18:31:11 wessels Exp $
  *
- * DEBUG: section 23	URL Parsing
+ * DEBUG: section 23    URL Parsing
  * AUTHOR: Duane Wessels
  *
  * SQUID Internet Object Cache  http://www.nlanr.net/Squid/
  * --------------------------------------------------------
  *
- *   Squid is the result of efforts by numerous individuals from the
- *   Internet community.  Development is led by Duane Wessels of the
- *   National Laboratory for Applied Network Research and funded by
- *   the National Science Foundation.
- * 
+ *  Squid is the result of efforts by numerous individuals from the
+ *  Internet community.  Development is led by Duane Wessels of the
+ *  National Laboratory for Applied Network Research and funded by
+ *  the National Science Foundation.
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *  
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *  
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  
  */
 
 #include "squid.h"
@@ -22,6 +35,7 @@ char *RequestMethodStr[] =
     "NONE",
     "GET",
     "POST",
+    "PUT",
     "HEAD",
     "CONNECT"
 };
@@ -116,6 +130,8 @@ method_t urlParseMethod(s)
 	return METHOD_GET;
     } else if (strcasecmp(s, "POST") == 0) {
 	return METHOD_POST;
+    } else if (strcasecmp(s, "PUT") == 0) {
+	return METHOD_PUT;
     } else if (strcasecmp(s, "HEAD") == 0) {
 	return METHOD_HEAD;
     } else if (strcasecmp(s, "CONNECT") == 0) {
